@@ -64,7 +64,9 @@ class _ApiCompatibilityContextManager(ContextManager):
             if api_version.is_devrelease:
                 api_version = parse(api_version.base_version)
             if not api_version >= self._min_version:
-                raise ApiCompatibilityError(str(self._min_version))
+                raise ApiCompatibilityError(
+                    str(self._min_version), api_version=api_version
+                )
         pass
 
     def __exit__(
