@@ -181,7 +181,6 @@ class DatasetBase:
         return dataset
 
     def _to_datasets_dict(self) -> Dict:
-        """Helper method to transform a argilla dataset into a dict that is compatible with `datasets.Dataset`"""
         raise NotImplementedError
 
     @classmethod
@@ -484,8 +483,8 @@ class DatasetBase:
             )
         elif framework is Framework.SPACY and lang is None:
             raise ValueError(
-                "Please provide a spacy language model to prepare the"
-                " dataset for training with the spacy framework."
+                "Please provide a spacy language model to prepare the dataset for"
+                " training with the spacy framework."
             )
         elif framework in [Framework.SPACY, Framework.SPARK_NLP]:
             if train_size and test_size:
@@ -847,7 +846,7 @@ class DatasetForTextClassification(DatasetBase):
                 },
                 features=datasets.Features(feature_dict),
             )
-        if test_size:
+        if test_size is not None and test_size != 0:
             ds = ds.train_test_split(
                 train_size=train_size, test_size=test_size, seed=seed
             )
@@ -1007,7 +1006,7 @@ class DatasetForTokenClassification(DatasetBase):
         for row in dataset:
             # TODO: fails with a KeyError if no tokens column is present and no mapping is indicated
             if not row["tokens"]:
-                _LOGGER.warning(f"Ignoring row with no tokens.")
+                _LOGGER.warning("Ignoring row with no tokens.")
                 continue
 
             if row.get("tags"):
@@ -1079,10 +1078,11 @@ class DatasetForTokenClassification(DatasetBase):
             .map(lambda example: {"ner_tags": spans2iob(example)})
         )
         new_features = ds.features.copy()
-        new_features["ner_tags"] = [class_tags]
+        new_features["ner_tags"] = datasets.Sequence(feature=class_tags)
         ds = ds.cast(new_features)
+        ds = ds.remove_columns(set(ds.column_names) - set(["tokens", "ner_tags"]))
 
-        if train_size or test_size:
+        if test_size is not None and test_size != 0:
             ds = ds.train_test_split(
                 train_size=train_size, test_size=test_size, seed=seed
             )
@@ -1155,6 +1155,7 @@ class DatasetForTokenClassification(DatasetBase):
 
     def _to_datasets_dict(self) -> Dict:
         """Helper method to put token classification records in a `datasets.Dataset`"""
+
         # create a dict first, where we make the necessary transformations
         def entities_to_dict(
             entities: Optional[
@@ -1352,17 +1353,36 @@ class DatasetForText2Text(DatasetBase):
         return cls([Text2TextRecord(**row) for row in dataframe.to_dict("records")])
 
     @_requires_datasets
-    def prepare_for_training(self, **kwargs) -> "datasets.Dataset":
-        """Prepares the dataset for training.
+    def _prepare_for_training_with_transformers(
+        self,
+        train_size: Optional[float] = None,
+        test_size: Optional[float] = None,
+        seed: Optional[int] = None,
+    ):
+        import datasets
 
-        Args:
-            **kwargs: Specific to the task of the dataset.
+        ds_dict = {"text": [], "target": []}
+        for rec in self._records:
+            if rec.annotation is None:
+                continue
+            ds_dict["text"].append(rec.text)
+            ds_dict["target"].append(rec.annotation)
 
-        Returns:
-            A datasets Dataset.
-        """
+        feature_dict = {
+            "text": datasets.Value("string"),
+            "target": datasets.Value("string"),
+        }
 
-        raise NotImplementedError
+        ds = datasets.Dataset.from_dict(
+            ds_dict, features=datasets.Features(feature_dict)
+        )
+
+        if test_size is not None and test_size != 0:
+            ds = ds.train_test_split(
+                train_size=train_size, test_size=test_size, seed=seed
+            )
+
+        return ds
 
 
 Dataset = Union[
