@@ -50,14 +50,21 @@ class ClientAdapterFactory:
 
         version, distribution = cls._fetch_cluster_version_info(client_config)
 
-        (client_class, support_vector_search) = cls._resolve_client_class_with_vector_support(version, distribution)
+        (
+            client_class,
+            support_vector_search,
+        ) = cls._resolve_client_class_with_vector_support(version, distribution)
 
         return client_class(
-            index_shards=index_shards, vector_search_supported=support_vector_search, config_backend=client_config
+            index_shards=index_shards,
+            vector_search_supported=support_vector_search,
+            config_backend=client_config,
         )
 
     @classmethod
-    def _resolve_client_class_with_vector_support(cls, version: str, distribution: str) -> Tuple[Type, bool]:
+    def _resolve_client_class_with_vector_support(
+        cls, version: str, distribution: str
+    ) -> Tuple[Type, bool]:
 
         support_vector_search = True
 
