@@ -16,6 +16,7 @@
 from pydantic import BaseSettings
 
 from argilla._constants import DEFAULT_API_KEY
+from argilla.server import helpers
 from argilla.server.settings import settings as server_settings
 
 
@@ -50,7 +51,9 @@ class Settings(BaseSettings):
     @property
     def public_oauth_token_url(self):
         """The final public token url used for openapi doc setup"""
-        return f"{server_settings.base_url}{self.token_api_url.removeprefix('/')}"
+        return (
+            f"{server_settings.base_url}{helpers.remove_prefix(self.token_api_url,'/')}"
+        )
 
     class Config:
         env_prefix = "ARGILLA_LOCAL_AUTH_"
